@@ -100,11 +100,17 @@ if (getRversion() >= "3.1.0") {
 #' reproducible workflow.
 #'
 #' @section useCache:
-#' If \code{FALSE}, then the entire Caching mechanism is bypassed and the
+#' Logical or numeric. If \code{FALSE} or \code{0}, then the entire Caching
+#' mechanism is bypassed and the
 #' function is evaluated as if it was not being Cached. Default is
 #' \code{getOption("reproducible.useCache")}), which is \code{TRUE} by default,
 #' meaning use the Cache mechanism. This may be useful to turn all Caching on or
-#' off in very complex scripts and nested functions.
+#' off in very complex scripts and nested functions. Increasing levels of numeric
+#' values will cause deeper levels of Caching to occur. Currently, only implemented
+#' in \code{postProcess}: to do both caching of inner \code{cropInputs}, \code{projectInputs}
+#' and \code{maskInputs}, and caching of outer \code{postProcess}, use
+#' \code{useCache = 2}; to skip the inner sequence of 3 functions, use \code{useCache = 1}.
+#' For large objects, this may prevent many duplicated save to disk events.
 #'
 #' If \code{"overwrite"}
 #' (which can be set with \code{options("reproducible.useCache" =
@@ -242,7 +248,7 @@ if (getRversion() >= "3.1.0") {
 #'        where Cache is not correctly detecting unchanged inputs. This will guarantee
 #'        the object will be identical each time; this may be useful in operational code.
 #'
-#' @param useCache Logical or \code{"overwrite"} or \code{"devMode"}. See details.
+#' @param useCache Logical, numeric or \code{"overwrite"} or \code{"devMode"}. See details.
 #'
 #' @param useCloud Logical. If \code{TRUE}, then this Cache call will download
 #'   (if local copy doesn't exist,
@@ -253,13 +259,14 @@ if (getRversion() >= "3.1.0") {
 #'   cloud folder gets large. If a user wishes to keep "high-level" control, set this to
 #'   \code{getOption("reproducible.useCloud", FALSE)} or
 #'   \code{getOption("reproducible.useCloud", TRUE)} (if the default behaviour should
-#'   be FALSE or TRUE, respectively) so it can be turned on and off with
+#'   be \code{FALSE} or \code{TRUE}, respectively) so it can be turned on and off with
 #'   this option. NOTE: \emph{This argument will not be passed into inner/nested Cache calls.})
 #'
-#' @param cloudFolderID A googledrive id of a folder, e.g., using \code{drive_mkdir()}. If
-#'   left as \code{NULL}, the function will create a cloud folder with a warning. The warning
-#'   will have the cloudFolderID that should be used in subsequent calls. It will also be
-#'   added to options("reproducible.cloudFolderID"), but this will not persist across sessions.
+#' @param cloudFolderID A googledrive id of a folder, e.g., using \code{drive_mkdir()}.
+#'   If left as \code{NULL}, the function will create a cloud folder with a warning.
+#'   The warning will have the \code{cloudFolderID} that should be used in subsequent calls.
+#'   It will also be added to \code{options("reproducible.cloudFolderID")},
+#'   but this will not persist across sessions.
 #'
 #' @param showSimilar A logical or numeric. Useful for debugging.
 #'        If \code{TRUE} or \code{1}, then if the Cache
@@ -354,7 +361,7 @@ setMethod(
     modifiedDots <- fnDetails$modifiedDots
     originalDots <- fnDetails$originalDots
 
-    if (isFALSE(useCache)) {
+    if (isFALSE(useCache) || isTRUE(0 == useCache)) {
       message(crayon::green("useCache is FALSE, skipping Cache.",
                             "To turn Caching on, use options(reproducible.useCache = TRUE)"))
       if (fnDetails$isDoCall) {
@@ -548,6 +555,10 @@ setMethod(
         lastEntry <- max(isInRepo$createdDate)
         lastOne <- order(isInRepo$createdDate, decreasing = TRUE)[1]
         if (is.null(notOlderThan) || (notOlderThan < lastEntry)) {
+          objSize <- file.size(file.path(cacheRepo, "gallery", paste0(isInRepo$artifact, ".rda")))
+          class(objSize) <- "object_size"
+          if (objSize > 1e6)
+            message(crayon::blue(paste0("  ...(Object to retrieve is large: ", format(objSize, units = "auto"), ")")))
           output <- try(.getFromRepo(FUN, isInRepo = isInRepo, notOlderThan = notOlderThan,
                                  lastOne = lastOne, cacheRepo = cacheRepo,
                                  fnDetails = fnDetails,
@@ -802,21 +813,28 @@ setMethod(
 
       if (isNullOutput) return(NULL) else return(output)
     }
-  })
-
+})
 
+#' @keywords internal
 .formalsCache <- formals(Cache)[-(1:2)]
+
+#' @keywords internal
 .formalsCache[c("compareRasterFileLength", "digestPathContent")] <- NULL
+
+#' @keywords internal
 .namesCacheFormals <- names(.formalsCache)[]
 
+#' @keywords internal
 .loadFromLocalRepoMem2 <- function(md5hash, ...) {
   out <- loadFromLocalRepo(md5hash, ...)
   out <- makeMemoisable(out)
   return(out)
 }
 
+#' @keywords internal
 .loadFromLocalRepoMem <- memoise::memoise(.loadFromLocalRepoMem2)
 
+#' @keywords internal
 .unlistToCharacter <- function(l, max.level = 1) {
   if (max.level > 0) {
     lapply(l, function(l1) {
@@ -1154,6 +1172,7 @@ CacheDigest <- function(objsToDigest, algo = "xxhash64", calledFrom = "Cache", .
   list(outputHash = res, preDigest = preDigest)
 }
 
+#' @keywords internal
 warnonce <- function(id, ...) {
   if (!isTRUE(get0(flag <- paste0("warned.", as.character(id)[1L]),
                    .reproEnv, ifnotfound = FALSE))) {
@@ -1173,7 +1192,7 @@ warnonce <- function(id, ...) {
   if (identical("devMode", useCache))
     showSimilar <- 1
   userTags2 <- .getOtherFnNamesAndTags(scalls = scalls)
-  userTags2 <- c(userTags2, paste("preDigest", names(preDigestUnlistTrunc), preDigestUnlistTrunc, sep = ":"))
+  userTags2 <- c(userTags2, paste("preDigest", names(preDigestUnlistTrunc), preDigestUnlistTrunc, sep = ":")) #nolint
   userTags3 <- c(userTags, userTags2)
   aa <- localTags[tag %in% userTags3][,.N, keyby = artifact]
   setkeyv(aa, "N")
@@ -1221,6 +1240,7 @@ warnonce <- function(id, ...) {
   }
 }
 
+#' @keywords internal
 getLocalTags <- function(cacheRepo) {
   written <- 0
   while (written >= 0) {
@@ -1239,18 +1259,21 @@ getLocalTags <- function(cacheRepo) {
   localTags
 }
 
+#' @keywords internal
 .defaultCacheOmitArgs <- c("useCloud", "checksumsFileID", "cloudFolderID",
-  "notOlderThan", ".objects", "outputObjects", "algo", "cacheRepo",
-  "length", "compareRasterFileLength", "userTags", "digestPathContent",
-  "omitArgs", "classOptions", "debugCache", "sideEffect", "makeCopy",
-  "quick", "verbose", "cacheId", "useCache", "showSimilar")
+                           "notOlderThan", ".objects", "outputObjects", "algo", "cacheRepo",
+                           "length", "compareRasterFileLength", "userTags", "digestPathContent",
+                           "omitArgs", "classOptions", "debugCache", "sideEffect", "makeCopy",
+                           "quick", "verbose", "cacheId", "useCache", "showSimilar")
 
+#' @keywords internal
 verboseTime <- function(verbose) {
   if (verbose > 1) {
     return(Sys.time())
   }
 }
 
+#' @keywords internal
 verboseMessage1 <- function(verbose, userTags) {
   if (verbose > 0)
     message("Using devMode; overwriting previous Cache entry with tags: ",
@@ -1258,6 +1281,7 @@ verboseMessage1 <- function(verbose, userTags) {
   invisible(NULL)
 }
 
+#' @keywords internal
 verboseMessage2 <- function(verbose) {
   if (verbose > 0)
     message("Using devMode; Found entry with identical userTags, ",
@@ -1265,14 +1289,15 @@ verboseMessage2 <- function(verbose) {
   invisible(NULL)
 }
 
+#' @keywords internal
 verboseMessage3 <- function(verbose, artifact) {
   if (length(unique(artifact)) > 1) {
     if (verbose > 0)
       message("Using devMode, but userTags are not unique; defaulting to normal useCache = TRUE")
   }
-
 }
 
+#' @keywords internal
 verboseDF1 <- function(verbose, functionName, startRunTime) {
   if (verbose > 1) {
     endRunTime <- Sys.time()
@@ -1287,10 +1312,10 @@ verboseDF1 <- function(verbose, functionName, startRunTime) {
     if (exists("verboseTiming", envir = .reproEnv)) {
       .reproEnv$verboseTiming <- rbind(.reproEnv$verboseTiming, verboseDF)
     }
-
   }
 }
 
+#' @keywords internal
 verboseDF2 <- function(verbose, functionName, startSaveTime) {
   if (verbose > 1) {
     endSaveTime <- Sys.time()
@@ -1309,6 +1334,7 @@ verboseDF2 <- function(verbose, functionName, startSaveTime) {
   }
 }
 
+#' @keywords internal
 verboseDF3 <- function(verbose, functionName, startCacheTime) {
   if (verbose > 1) {
     endCacheTime <- Sys.time()
@@ -1325,6 +1351,7 @@ verboseDF3 <- function(verbose, functionName, startCacheTime) {
   }
 }
 
+#' @keywords internal
 determineNestedTags <- function(envir, mc, userTags) {
   argsNoNesting <- "useCloud"
   if (R.version[['minor']] <= "4.0") {
@@ -1404,34 +1431,39 @@ getCacheRepos <- function(cacheRepo, modifiedDots) {
   return(cacheRepos)
 }
 
-devModeFn1 <- function(localTags, userTags, scalls, preDigestUnlistTrunc, useCache, verbose, isInRepo, outputHash) {
+devModeFn1 <- function(localTags, userTags, scalls, preDigestUnlistTrunc, useCache, verbose,
+                       isInRepo, outputHash) {
   isInRepoAlt <- localTags[localTags$tag %in% userTags, , drop = FALSE]
   data.table::setDT(isInRepoAlt)
   isInRepoAlt <- isInRepoAlt[, iden := identical(sum(tag %in% userTags), length(userTags)),
                              by = "artifact"][iden == TRUE]
   if (NROW(isInRepoAlt) > 0 && length(unique(isInRepoAlt$artifact)) == 1) {
     newLocalTags <- localTags[localTags$artifact %in% isInRepoAlt$artifact,]
-    tags1 <- grepl("(format|name|class|date|cacheId|function|object.size|accessed|otherFunctions|preDigest)",
+    tags1 <- grepl(paste0("(",
+                          paste("accessed", "cacheId", "class", "date", "format", "function",
+                                "name", "object.size", "otherFunctions", "preDigest",
+                                sep = "|"),
+                          ")"),
                    newLocalTags$tag)
     localTagsAlt <- newLocalTags[!tags1,]
     if (all(localTagsAlt$tag %in% userTags)) {
-      mess <- capture.output(type = "output",
-                             similars <- .findSimilar(newLocalTags, scalls = scalls,
-                                                      preDigestUnlistTrunc = preDigestUnlistTrunc,
-                                                      userTags = userTags,
-                                                      useCache = useCache))
+      mess <- capture.output(type = "output", {
+        similars <- .findSimilar(newLocalTags, scalls = scalls,
+                                 preDigestUnlistTrunc = preDigestUnlistTrunc,
+                                 userTags = userTags,
+                                 useCache = useCache)
+      })
       similarsHaveNA <- sum(is.na(similars$differs))
       #similarsAreDifferent <- sum(similars$differs == TRUE, na.rm = TRUE)
       #likelyNotSame <- sum(similarsHaveNA, similarsAreDifferent)/NROW(similars)
 
       if (similarsHaveNA < 2) {
         verboseMessage1(verbose, userTags)
-        outputHash <- gsub("cacheId:", "",  newLocalTags[newLocalTags$artifact %in% isInRepoAlt$artifact &
-                                                           startsWith(newLocalTags$tag, "cacheId"), ]$tag)
+        outputHash <- gsub("cacheId:", "", newLocalTags[newLocalTags$artifact %in% isInRepoAlt$artifact & #nolint
+                                                          startsWith(newLocalTags$tag, "cacheId"), ]$tag) #nolint
         isInRepo <- isInRepoAlt
       } else {
         verboseMessage2(verbose)
-
       }
     }
     needFindByTags <- TRUE # it isn't there
