@@ -5,6 +5,9 @@
 #'           See individual methods.
 #' @importClassesFrom quickPlot spatialObjects
 #' @importFrom utils capture.output
+#' @importFrom raster buffer
+#' @importFrom sf st_is_longlat
+#' @importFrom sp spTransform
 #' @seealso \code{prepInputs}
 #' @inheritParams prepInputs
 #' @rdname postProcess
@@ -149,12 +152,12 @@ postProcess.spatialObjects <- function(x, filename1 = NULL, filename2 = TRUE,
                                        useCache = getOption("reproducible.useCache", FALSE),
                                        ...) {
   # Test if user supplied wrong type of file for "studyArea", "rasterToMatch"
-  x <- postProcessAllSpatial(x = x, studyArea = studyArea,
+  x1 <- postProcessAllSpatial(x = x, studyArea = studyArea,
                              rasterToMatch = rasterToMatch, useCache = useCache,
                              filename1 =filename1, filename2 = filename2,
                              useSAcrs = useSAcrs, overwrite = overwrite,
                              ...)
-  return(x)
+  return(x1)
 }
 
 #' @export
@@ -392,9 +395,9 @@ fixErrors.SpatialPolygons <- function(x, objectName = NULL,
       message("Checking for errors in ", objectName)
       if (suppressWarnings(any(!rgeos::gIsValid(x, byid = TRUE)))) {
         message("Found errors in ", objectName, ". Attempting to correct.")
-        warn <- capture_warnings(
+        warn <- capture_warnings({
           x1 <- try(Cache(raster::buffer, x, width = 0, dissolve = FALSE, useCache = useCache))
-        )
+        })
 
         # prevent the warning about not projected, because we are buffering 0, which doesn't matter
         warnAboutNotProjected <- startsWith(warn, "Spatial object is not projected; GEOS expects planar coordinates")
@@ -434,12 +437,13 @@ fixErrors.sf <- function(x, objectName = NULL, attemptErrorFixes = TRUE,
       message("Checking for errors in ", objectName)
       if (suppressWarnings(any(!sf::st_is_valid(x)))) {
         message("Found errors in ", objectName, ". Attempting to correct.")
-        warn <- capture_warnings(
+        warn <- capture_warnings({
           x1 <- try(Cache(sf::st_buffer, x, dist = 0, useCache = useCache))
-        )
+        })
 
         # prevent the warning about not projected, because we are buffering 0, which doesn't matter
-        warnAboutNotProjected <- startsWith(warn, "Spatial object is not projected; GEOS expects planar coordinates")
+        warnAboutNotProjected <- startsWith(warn, paste("Spatial object is not projected;",
+                                                        "GEOS expects planar coordinates"))
         if (any(warnAboutNotProjected))
           warn <- warn[!warnAboutNotProjected]
         if (length(warn))
@@ -496,7 +500,7 @@ projectInputs.default <- function(x, targetCRS, ...) {
 
 #' @export
 #' @rdname projectInputs
-#' @param useGDAL Logical, defaults to getOption("reproducible.useGDAL" = TRUE).
+#' @param useGDAL Logical, defaults to \code{getOption("reproducible.useGDAL" = TRUE)}.
 #'     If \code{TRUE}, then this function will use \code{gdalwarp} only when not
 #'     small enough to fit in memory (i.e., \emph{if the operation fails} the
 #'     \code{raster::canProcessInMemory(x, 3)} test). Using \code{gdalwarp} will
@@ -508,6 +512,7 @@ projectInputs.default <- function(x, targetCRS, ...) {
 #' @importFrom gdalUtils gdal_setInstallation gdalwarp
 #' @importFrom parallel detectCores
 #' @importFrom raster crs dataType res res<- dataType<-
+#' @importFrom testthat capture_warnings
 projectInputs.Raster <- function(x, targetCRS = NULL, rasterToMatch = NULL, cores = NULL,
                                  useGDAL = getOption("reproducible.useGDAL", TRUE),
                                  ...) {
@@ -542,7 +547,7 @@ projectInputs.Raster <- function(x, targetCRS = NULL, rasterToMatch = NULL, core
         ## rasters need to go to same file so it can be unlinked at end without losing other temp files
         tmpRasPath <- checkPath(file.path(raster::tmpDir(), "bigRasters"), create = TRUE)
         tempSrcRaster <- file.path(tmpRasPath, "bigRasInput.tif")
-        tempDstRaster <- file.path(tmpRasPath, paste0(x@data@names, "a_reproj.tif")) #fails if x = stack
+        tempDstRaster <- file.path(tmpRasPath, paste0(x@data@names, "a_reproj.tif")) # fails if x = stack
 
         if (!is.null(rasterToMatch)) {
           tr <- res(rasterToMatch)
@@ -581,13 +586,13 @@ projectInputs.Raster <- function(x, targetCRS = NULL, rasterToMatch = NULL, core
                                           extent(rasterToMatch)@xmax, " ",
                                           extent(rasterToMatch)@ymax, " "))
         }
-        if (is.null(cores) || cores =="AUTO") {
-          cores <- as.integer(parallel::detectCores()*0.9)
+        if (is.null(cores) || cores == "AUTO") {
+          cores <- as.integer(parallel::detectCores() * 0.9)
           prll <- paste0("-wo NUM_THREADS=", cores, " ")
         } else {
           if (!is.integer(cores)) {
             if (is.character(cores) | is.logical(cores)) {
-              stop ("'cores' needs to be passed as numeric or 'AUTO'")
+              stop("'cores' needs to be passed as numeric or 'AUTO'")
             } else {
               prll <- paste0("-wo NUM_THREADS=", as.integer(cores), " ")
             }
@@ -643,13 +648,16 @@ projectInputs.Raster <- function(x, targetCRS = NULL, rasterToMatch = NULL, core
 
         if (is.null(rasterToMatch)) {
           Args <- append(dots, list(from = x, crs = targetCRS))
-          warn <- capture_warnings(x <- do.call(projectRaster, args = Args))
-
+          warn <- capture_warnings({
+            x <- do.call(projectRaster, args = Args)
+          })
         } else {
           # projectRaster does silly things with integers, i.e., it converts to numeric
           tempRas <- projectExtent(object = rasterToMatch, crs = targetCRS)
           Args <- append(dots, list(from = x, to = tempRas))
-          warn <- capture_warnings(x <- do.call(projectRaster, args = Args))
+          warn <- capture_warnings({
+            x <- do.call(projectRaster, args = Args)
+          })
 
           if (identical(crs(x), crs(rasterToMatch)) & any(res(x) != res(rasterToMatch))) {
             if (all(res(x) %==% res(rasterToMatch))) {
@@ -698,7 +706,8 @@ projectInputs.sf <- function(x, targetCRS, ...) {
   if (!is.null(targetCRS)) {
     warning("sf class objects not fully tested Use with caution.")
     if (requireNamespace("sf")) {
-      if (any(sf::st_is(x, c("POLYGON", "MULTIPOLYGON"))) && !any(isValid <- sf::st_is_valid(x))) {
+      isValid <- sf::st_is_valid(x)
+      if (any(sf::st_is(x, c("POLYGON", "MULTIPOLYGON"))) && !any(isValid)) {
         x[!isValid] <- sf::st_buffer(x[!isValid], dist = 0, ...)
       }
 
@@ -746,8 +755,8 @@ projectInputs.Spatial <- function(x, targetCRS, ...) {
 #' This is the function that follows the table of order of
 #' preference for determining CRS. See \code{\link{postProcess}}
 #' @inheritParams postProcess.spatialObjects
-#' @rdname postProcessHelpers
 #' @keywords internal
+#' @rdname postProcessHelpers
 .getTargetCRS <- function(useSAcrs, studyArea, rasterToMatch, targetCRS = NULL) {
   if (is.null(targetCRS)) {
     targetCRS <- if (useSAcrs) {
@@ -1059,6 +1068,7 @@ writeOutputs.Raster <- function(x, filename2 = NULL,
   x
 }
 
+#' @importFrom testthat capture_warnings
 #' @rdname writeOutputs
 writeOutputs.Spatial <- function(x, filename2 = NULL,
                                  overwrite = getOption("reproducible.overwrite", TRUE),
@@ -1330,12 +1340,50 @@ postProcessAllSpatial <- function(x, studyArea, rasterToMatch, useCache, filenam
       extRTM <- NULL
       crsRTM <- NULL
     }
+    useBuffer <- FALSE
+    bufferSA <- FALSE
+
+    if (class(x) == "RasterLayer") {
+      #if all CRS are projected, then check if buffer is necessary
+      projections <- sapply(list(x, studyArea, crsRTM), FUN = sf::st_is_longlat)
+      projections <- na.omit(projections)
+      if (!any(projections)) {
+        if (is.null(rasterToMatch) || max(res(rasterToMatch)) < min(res(x))) {
+          useBuffer <- TRUE
+        }
+      }
+    }
+
+    if (useBuffer) {
+      #replace extentRTM and crsRTM, because they will supersede all arguments
+      if (!is.null(rasterToMatch)) {
+        #reproject rasterToMatch, extend by res
+        newExtent <- projectExtent(rasterToMatch, crs = crs(x))
+        tempPoly <- as(extent(newExtent), "SpatialPolygons")
+        crs(tempPoly) <- crs(x)
+        #buffer the new polygon by 1.5 the resolution of X so edges aren't cropped out
+        tempPoly <- raster::buffer(tempPoly, width = max(res(x))*1.5)
+        extRTM <- tempPoly
+        crsRTM <- crs(tempPoly)
+      } else {
+        bufferSA <- TRUE
+        origStudyArea <- studyArea
+        studyArea <- sp::spTransform(studyArea, CRSobj = crs(x))
+        studyArea <- raster::buffer(studyArea, width = max(res(x)) * 1.5)
+        #confirm you could only pass study area, because buffering will require reprojecting first.
+        #buffer studyArea
+      }
+    }
 
     x <- Cache(cropInputs, x = x, studyArea = studyArea,
                extentToMatch = extRTM,
                extentCRS = crsRTM,
                useCache = useCache, ...)
 
+    if (bufferSA) {
+      studyArea <- origStudyArea
+    }
+
     # cropInputs may have returned NULL if they don't overlap
     if (!is.null(x)) {
       objectName <- if (is.null(filename1)) NULL else basename(filename1)
