@@ -15,6 +15,7 @@ testInit <- function(libraries, ask = FALSE, verbose = FALSE, tmpFileExt = "",
     options("reproducible.ask" = ask)
   else
     list()
+
   optsVerbose <- if (verbose)
     options(reproducible.verbose = verbose)
   else
@@ -26,22 +27,33 @@ testInit <- function(libraries, ask = FALSE, verbose = FALSE, tmpFileExt = "",
   tmpdir <- normPath(file.path(tempdir(), rndstr(1, 6)))
 
   if (isTRUE(needGoogle)) {
-    googledrive::drive_auth_config(active = TRUE)
+    if (utils::packageVersion("googledrive") >= "1.0.0")
+      googledrive::drive_deauth()
+    else
+      googledrive::drive_auth_config(active = TRUE)
+
     if (quickPlot::isRstudioServer()) {
       options(httr_oob_default = TRUE)
     }
 
+    ## #119 changed use of .httr-oauth (i.e., no longer used)
+    ## instead, uses ~/.R/gargle/gargle-oauth/long_random_token_name_with_email
     if (interactive()) {
-      if (file.exists("~/.httr-oauth")) {
-        linkOrCopy("~/.httr-oauth", to = file.path(tmpdir, ".httr-oauth"))
-      } else {
+      if (utils::packageVersion("googledrive") >= "1.0.0") {
         googledrive::drive_auth()
-        print("copying .httr-oauth to ~/.httr-oauth")
-        file.copy(".httr-oauth", "~/.httr-oauth", overwrite = TRUE)
+      } else {
+        if (file.exists("~/.httr-oauth")) {
+          linkOrCopy("~/.httr-oauth", to = file.path(tmpdir, ".httr-oauth"))
+        } else {
+          googledrive::drive_auth()
+          print("copying .httr-oauth to ~/.httr-oauth")
+          file.copy(".httr-oauth", "~/.httr-oauth", overwrite = TRUE)
+        }
+
+        if (!file.exists("~/.httr-oauth"))
+          message("Please put an .httr-oauth file in your ~ directory")
       }
     }
-    if (!file.exists("~/.httr-oauth")) message("Please put an .httr-oauth file in your ~ directory")
-
   }
   checkPath(tmpdir, create = TRUE)
   origDir <- setwd(tmpdir)
@@ -54,8 +66,12 @@ testInit <- function(libraries, ask = FALSE, verbose = FALSE, tmpFileExt = "",
 
   if (!is.null(opts)) {
     if (needGoogle) {
-      optsGoogle <- list(httr_oob_default = quickPlot::isRstudioServer(),
-                         httr_oauth_cache = "~/.httr-oauth")
+      optsGoogle <- if (utils::packageVersion("googledrive") >= "1.0.0") {
+        list(httr_oob_default = quickPlot::isRstudioServer(),
+             httr_oauth_cache = "~/.httr-oauth")
+      } else {
+        list(httr_oob_default = quickPlot::isRstudioServer())
+      }
       opts <- append(opts, optsGoogle)
     }
     opts <- options(opts)
@@ -89,24 +105,24 @@ testOnExit <- function(testInitOut) {
     options(testInitOut$opts)
   setwd(testInitOut$origDir)
   unlink(testInitOut$tmpdir, recursive = TRUE)
-  if (isTRUE(testInitOut$needGoogle))
-    googledrive::drive_auth_config(active = FALSE)
+  if (isTRUE(testInitOut$needGoogle)) {
+    if (utils::packageVersion("googledrive") < "1.0.0")
+      googledrive::drive_auth_config(active = FALSE)
+  }
   lapply(testInitOut$libs, function(lib) {
     detach(paste0("package:", lib), character.only = TRUE)}
   )
 }
 
-runTest <- function(prod, class, numFiles, mess, expectedMess, filePattern, tmpdir,
-                    test) {
+runTest <- function(prod, class, numFiles, mess, expectedMess, filePattern, tmpdir, test) {
   files <- dir(tmpdir, pattern = filePattern, full.names = TRUE)
   expect_true(length(files) == numFiles)
   expect_is(test, class)
   message(mess)
-  print(hasMessageNum <-
-          paste(collapse = "_", which(unlist(
-            lapply(strsplit(expectedMess, "\\|")[[1]], function(m)
-              any(grepl(m, mess)))
-          ))))
+  hasMessageNum <- print(paste(collapse = "_", which(unlist(
+    lapply(strsplit(expectedMess, "\\|")[[1]], function(m)
+      any(grepl(m, mess)))
+  ))))
 
   isOK <- hasMessageNum == prod
   if (!isOK) {
@@ -120,7 +136,6 @@ runTest <- function(prod, class, numFiles, mess, expectedMess, filePattern, tmpd
   expect_true(isOK) #
 }
 
-
 expectedMessageRaw <- c("Running preP", "Preparing:", "File downloaded",
                         "From:Shapefile", "Checking local", "Finished checking",
                         "Downloading", "Skipping download", "Skipping extractFrom",
