@@ -1,25 +1,25 @@
 test_that("test Copy", {
-  library(raster)
-  library(data.table)
+  testInitOut <- testInit(c("raster", "data.table"), tmpFileExt = ".tif")
+  on.exit({
+    testOnExit(testInitOut)
+  }, add = TRUE)
 
   ras <- raster(extent(0, 10, 0, 10), vals = 1)
-  tmpRasFilename <- tempfile("tmpRas", fileext = ".tif")
-  tmpDir <- file.path(tempdir(), "ras")
-  checkPath(tmpDir, create = TRUE); on.exit(unlink(tmpDir, recursive = TRUE), add = TRUE)
-  ras <- writeRaster(ras, filename = tmpRasFilename, overwrite = TRUE)
-  ras2 <- Copy(ras, tmpDir)
+  ras <- writeRaster(ras, filename = tmpfile, overwrite = TRUE)
+  ras2 <- Copy(ras, tmpdir)
   expect_true(all.equal(ras2[], ras[]))
   expect_false(filename(ras2) == filename(ras))
 
   dt <- data.table(a = 1:2, b = rev(LETTERS[1:2]))
-  tmpDir <- file.path(tempdir(), "ras2")
+  tmpdir <- normPath(file.path(tempdir(), "ras2"))
+  checkPath(tmpdir, create = TRUE); on.exit(unlink(tmpdir, recursive = TRUE), add = TRUE)
   li <- list(dt = dt, ras = ras, ras2 = ras2)
-  li2 <- Copy(li, tmpDir)
+  li2 <- Copy(li, tmpdir)
 
   # same content
   expect_true(all(unlist(lapply(seq_along(li), function(i) {
     if (is(li[[i]], "Raster")) {
-       all.equal(li[[i]][], li2[[i]][])
+       all.equal(getValues(li[[i]]), raster::getValues(li2[[i]]))
      } else {
       all.equal(li[[i]], li2[[i]])
     }
@@ -39,8 +39,8 @@ test_that("test Copy", {
   li <- list(dt = dt, ras = ras, ras2 = ras2)
   li <- list2env(li, env = new.env())
 
-  tmpDir <- file.path(tempdir(), "ras3")
-  li2 <- Copy(li, tmpDir)
+  tmpdir <- file.path(tempdir(), "ras3")
+  li2 <- Copy(li, tmpdir)
 
   expect_true(all(unlist(lapply(names(li), function(i) {
     if (is(li[[i]], "Raster")) {
@@ -67,8 +67,8 @@ test_that("test Copy", {
   liEnv <- list2env(li, env = env1)
   liEnv[["env"]] <- li
 
-  tmpDir <- file.path(tempdir(), "ras3")
-  liEnv2 <- Copy(liEnv, tmpDir)
+  tmpdir <- file.path(tempdir(), "ras3")
+  liEnv2 <- Copy(liEnv, tmpdir)
 
   expect_true(all(unlist(lapply(names(liEnv[["env"]]), function(i) {
     if (is(li[[i]], "Raster")) {
@@ -76,7 +76,6 @@ test_that("test Copy", {
     } else {
       all.equal(liEnv[["env"]][[i]], liEnv2[["env"]][[i]])
     }
-
   }))))
 
   # different filenames for Rasters
