@@ -6,7 +6,7 @@ test_that("prepInputs in a simple one double nested zip file, passing only desti
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterNested.zip"
-  testZip <- reproducible::prepInputs(url = url, destinationPath = tempdir())
+  testZip <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
   expect_true(exists("testZip"))
 })
 
@@ -20,7 +20,7 @@ test_that("prepInputs in a simple one double nested zip file, passing targetFile
   url <- "https://github.com/tati-micheletti/host/raw/master/data/rasterNested.zip"
   testZip2 <- reproducible::prepInputs(url = url,
                              targetFile = "rasterTest.tif",
-                             destinationPath = tempdir())
+                             destinationPath = tmpdir)
   expect_true(exists("testZip2"))
 })
 
@@ -32,7 +32,7 @@ test_that("prepInputs in a two files double nested zip file, passing only destin
   }, add = TRUE)
 
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesOutter.zip"
-  testZip3 <- reproducible::prepInputs(url = url, destinationPath = tempdir())
+  testZip3 <- reproducible::prepInputs(url = url, destinationPath = tmpdir)
   expect_true(exists("testZip3"))
 })
 
@@ -46,7 +46,7 @@ test_that("prepInputs in a two files double nested zip file, passing targetFile"
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesOutter.zip"
   testZip4 <- reproducible::prepInputs(url = url,
                                        targetFile = "rasterTest.tif",
-                                       destinationPath = tempdir())
+                                       destinationPath = tmpdir)
   expect_true(exists("testZip4"))
 })
 
@@ -66,7 +66,7 @@ test_that(
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
   # The warning is about the .prj file missing, which is not relevant here -
   #   Capture it and do nothing with it
-  warn <- capture_warnings(testZip6 <- reproducible::prepInputs(url = url, destinationPath = tempdir()))
+  warn <- capture_warnings(testZip6 <- reproducible::prepInputs(url = url, destinationPath = tmpdir))
   expect_true(exists("testZip6"))
   expect_is(testZip6, "SpatialPolygonsDataFrame")
 })
@@ -83,7 +83,7 @@ test_that(
   url <- "https://github.com/tati-micheletti/host/raw/master/data/multiFilesMultiLevels.zip"
   testZip7 <- reproducible::prepInputs(url = url,
                                        targetFile = "rasterTest.tif",
-                                       destinationPath = tempdir())
+                                       destinationPath = tmpdir)
   expect_true(exists("testZip7"))
   expect_is(testZip7, "RasterLayer")
 })
@@ -100,11 +100,11 @@ test_that(paste("prepInputs in a two files double nested rar file,",
   if (is.null(hasUnrar)) {
     expect_error(testRar <- reproducible::prepInputs(
       url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
-      destinationPath = tempdir()))
+      destinationPath = tmpdir))
   } else {
     testRar <- reproducible::prepInputs(
       url = "https://github.com/tati-micheletti/host/raw/master/data/nestedRarTxtFiles.rar",
-      destinationPath = tempdir())
+      destinationPath = tmpdir)
     expect_true(exists("testRar"))
     expect_is(testRar, "RasterLayer")
   }
@@ -125,11 +125,11 @@ test_that(
   if (is.null(hasUnrar)) {
     expect_error(testRar2 <- reproducible::prepInputs(url = url,
                                                       targetFile = "rasterTOtestRAR.tif",
-                                                      destinationPath = tempdir()))
+                                                      destinationPath = tmpdir))
   } else {
     testRar2 <- reproducible::prepInputs(url = url,
                                          targetFile = "rasterTOtestRAR.tif",
-                                         destinationPath = tempdir())
+                                         destinationPath = tmpdir)
     expect_true(exists("testRar2"))
     expect_is(testRar2, "RasterLayer")
   }
@@ -149,12 +149,12 @@ test_that(paste0("prepInputs in a two files double nested rar file, with the wan
     expect_error(testRar3 <- reproducible::prepInputs(url = url,
                                                       archive = "nestedRarTxtFiles.rar",
                                                       targetFile = "rasterTOtestRAR.tif",
-                                                      destinationPath = tempdir()))
+                                                      destinationPath = tmpdir))
   } else {
     testRar3 <- reproducible::prepInputs(url = url,
                                          archive = "nestedRarTxtFiles.rar",
                                          targetFile = "rasterTOtestRAR.tif",
-                                         destinationPath = tempdir())
+                                         destinationPath = tmpdir)
     expect_true(exists("testRar3"))
     expect_is(testRar3, "RasterLayer")
   }
@@ -174,12 +174,12 @@ test_that("prepInputs works with nested rar file inside internal rar folder", {
   if (is.null(hasUnrar)) {
     expect_error(testRar4 <- reproducible::prepInputs(url = url,
                                                       targetFile = "rasterTest.tif",
-                                                      destinationPath = tempdir(),
+                                                      destinationPath = tmpdir,
                                                       useCache = FALSE))
   } else {
     testRar4 <- reproducible::prepInputs(url = url,
                                          targetFile = "rasterTest.tif",
-                                         destinationPath = tempdir(),
+                                         destinationPath = tmpdir,
                                          useCache = FALSE)
     expect_true(exists("testRar4"))
     expect_is(testRar4, "RasterLayer")
